from jinja2 import PackageLoader
from sugarbowl import cachedproperty
from .formatter import Formatter


class ManualFormatter(Formatter):

    # Public

    @cachedproperty
    def loader(self):
        return PackageLoader('clyde.formatter', 'templates/manual')
